# CHANGELOG

## v0.1.0 (2023-11-24)

### Documentation

* docs: update readme file ([`a43c26d`](https://github.com/crabisoft/pdbstore/commit/a43c26dbb1c9dc796caa977cf5de042f2bdf48f2))

### Feature

* feat: add conda-forge deployment (#9) ([`0357d62`](https://github.com/crabisoft/pdbstore/commit/0357d62be13fb64dbe2acd3564663a10479625be))

* feat: add unused command (#8) ([`23c2450`](https://github.com/crabisoft/pdbstore/commit/23c24500ff5a176eff720dd3ebde7fbd3951773e))

### Fix

* fix: wrong scripts definition from project file (#7) ([`55d9096`](https://github.com/crabisoft/pdbstore/commit/55d9096082acfc36376aff4dd3a8e5852767dc94))

## v0.0.2 (2023-11-09)

### Chore

* chore(ci): improve release workflow (#2) ([`4e47cbc`](https://github.com/crabisoft/pdbstore/commit/4e47cbc276ee14cbc7587ce513d24da669624b78))

### Ci

* ci(actions): improve release workflow (#1) ([`a8f7d60`](https://github.com/crabisoft/pdbstore/commit/a8f7d6000f8c7a200ee25e527c1f7b8fa07841c3))

### Documentation

* docs: update contributing guide (#4) ([`70908ee`](https://github.com/crabisoft/pdbstore/commit/70908ee11a3d8899502fdc5c88ba8713f446589b))

### Fix

* fix(io): need to rename file when decompressing it on windows (#6) ([`676df06`](https://github.com/crabisoft/pdbstore/commit/676df0600364749a031be05d72cd1a0127d55e7c))

### Test

* test: add more tests to improve cover (#5) ([`64347a3`](https://github.com/crabisoft/pdbstore/commit/64347a374c68bb18c75312de94345157bc0296c2))

* test: review tests to improve coverage (#3) ([`c1e211a`](https://github.com/crabisoft/pdbstore/commit/c1e211ac2384b1788a17c5f6d029b3ef9362550a))

## v0.0.1 (2023-10-25)

* Initial release